#include "clean.h"

//
// If the argument "autoRecurs" is true, this function returns
// a character, which means, user has typed in an 'A' in the directory
// which is in upper level of the current directory.
//
// If the argument "autoRecurs" is false, it will ask for user's instruction
// if the nonessential files in the current directory can be deleted. 
// It get user's answer, and return it.
//

char clean::getUserAnswer(const bool autoRecurs)
{
	char answer;

	// visiting a directory. Need to ask for user's input.
	if (autoRecurs) {
		// If automatically delete files, return 'A'
		return 'A';
	} else {
		do {
		cout << "You wanna delete all the non-essential files in the currnt directory?" << endl;
		cout << "Please enter (Y) to delete the files in this directory. " << endl;
		cout << "(N) to skip this directory" << endl;
		cout << "(A) to delete all the nonessntial files" << endl;
		cout << "    in this directory and its subdirectories" << endl;
		cin >> answer;
		} while (answer != 'Y' && answer != 'y'
			&& answer != 'N' && answer != 'n'
			&& answer != 'A' && answer != 'a');

		if (answer == 'A' || answer == 'a') {
			return 'A';
		} else if (answer == 'Y' || answer == 'y') {
			return 'Y';
		} else {
			return 'N';
		}
	}
}

//
// This function check the argument "userAnswer",
// If it is not 'N', the function keeps the nonessential files
// in the current directory.
//
void clean::performF(const char * fName, const char userAnswer)
{
	if ( userAnswer == 'N' ) {
		return;
	} else {
		cleanFile(fName);
		return;
	}
}

// Compare the extension of the fName and match it with
// the specified types to decide if it should be deleted
void clean::cleanFile(const char * fName)
{
	char *fNameExt;
	int i;

	// Copy the extension of the filename 
	// to a string.
	i = strlen(fName);
	while (fName[i] != '.' && i > 0) {
		i--;
	}

	// If this file has no extension name, 
	// don't do anything;
	if ( i == 0 ) return;

	fNameExt = (char *) malloc(strlen(fName) - i);
	strcpy(fNameExt, fName + i + 1);

	// compare the filename extension with
	// the known file extensions to decide
	// if we delete a file.
	if (   strcmp(_strupr(fNameExt), "CPP" ) == 0 
		|| strcmp(_strupr(fNameExt), "DLL" ) == 0 
		|| strcmp(_strupr(fNameExt), "EXE" ) == 0 
		|| strcmp(_strupr(fNameExt), "H" ) == 0 
		|| strcmp(_strupr(fNameExt), "HPP" ) == 0 
		|| strcmp(_strupr(fNameExt), "REG" ) == 0 
		|| strcmp(_strupr(fNameExt), "RES" ) == 0 )
		return;
	else {
		DeleteFile(fName);
		return;
	}
}

//----< test stub >--------------------------------------------
/* int main(int argc, char *argv[])
{
  clean * visitor = new clean;
  cout << "\n  Demonstrating Directory clean nonessential files! \n"
       << "\n ===================================================\n\n";

  char curDir[ 256 ];

  if( !GetCurrentDirectory( 256, curDir ) ) {
    cerr << "Couldn't get the current directory." << endl;
    return( 1 );
  }

  // List all files, starting with the current directory
  visitor->traverse(curDir, "*.*", false);
  cout << endl;

  // visitor->traverse(curDir, "*.*");
  // cout << endl;

  return 0;
} */